@@ -4,7 +4,7 @@ from web3 import Web3
 
 
 def validate_checksumed_address(address):
-    address = Web3.toChecksumAddress(address.lower())
+    address = Web3.toAddressChecksum(address.lower())
     if not Web3.isChecksumAddress(address):
         raise ValidationError(
             '%(address)s has an invalid checksum',
